Here I am creating two plugins:
1) Animal Sounds.
2) Patch Tracker.

Animal Sounds is the NetBox plugin from the documentation.

Patch Tracker is Dan's NetBox plugin for tracking pre-patches inside Pilot's instance of NetBox.

Documentation of this process are [[https://roamresearch.com/#/app/dans_life/page/0F1dqbyqT][being written here, in Roam.]]
